@@ -1547,11 +1547,11 @@ bool attack::apply_damage_brand(const char *what)
     {
         if (!weapon
             || damage_done < 1
-            || defender->is_summoned()
-            || !(defender->holiness() & MH_NATURAL)
+            || !actor_is_susceptible_to_vampirism(*defender)
             || attacker->stat_hp() == attacker->stat_maxhp()
             || attacker->is_player() && you.duration[DUR_DEATHS_DOOR]
-            || x_chance_in_y(2, 5) && !is_unrandom_artefact(*weapon, UNRAND_LEECH))
+            || x_chance_in_y(2, 5)
+               && !is_unrandom_artefact(*weapon, UNRAND_LEECH))
         {
             break;
         }
