@@ -273,7 +273,7 @@ static void _sdump_visits(dump_params &par)
         seen = "saw";
     }
 
-    vector<PlaceInfo> branches_visited = you.get_all_place_info(true, true);
+    const vector<PlaceInfo> branches_visited = you.get_all_place_info(true, true);
 
     PlaceInfo branches_total;
     for (const PlaceInfo &branch : branches_visited)
@@ -289,62 +289,70 @@ static void _sdump_visits(dump_params &par)
                              seen.c_str(), branches_total.levels_seen);
     }
 
-    PlaceInfo place_info = you.get_place_info(BRANCH_PANDEMONIUM);
-    if (place_info.num_visits > 0)
     {
-        text += make_stringf("You %svisited Pandemonium %d time",
-                             have.c_str(), place_info.num_visits);
-        if (place_info.num_visits > 1)
-            text += "s";
-        text += make_stringf(", and %s %d of its levels.\n",
-                             seen.c_str(), place_info.levels_seen);
+        const PlaceInfo place_info = you.get_place_info(BRANCH_PANDEMONIUM);
+        if (place_info.num_visits > 0)
+        {
+            text += make_stringf("You %svisited Pandemonium %d time",
+                                 have.c_str(), place_info.num_visits);
+            if (place_info.num_visits > 1)
+                text += "s";
+            text += make_stringf(", and %s %d of its levels.\n",
+                                 seen.c_str(), place_info.levels_seen);
+        }
     }
 
-    place_info = you.get_place_info(BRANCH_ABYSS);
-    if (place_info.num_visits > 0)
     {
-        text += make_stringf("You %svisited the Abyss %d time",
-                             have.c_str(), place_info.num_visits);
-        if (place_info.num_visits > 1)
-            text += "s";
-        text += ".\n";
+        const PlaceInfo place_info = you.get_place_info(BRANCH_ABYSS);
+        if (place_info.num_visits > 0)
+        {
+            text += make_stringf("You %svisited the Abyss %d time",
+                                 have.c_str(), place_info.num_visits);
+            if (place_info.num_visits > 1)
+                text += "s";
+            text += ".\n";
+        }
     }
 
-    place_info = you.get_place_info(BRANCH_BAZAAR);
-    if (place_info.num_visits > 0)
     {
-        text += make_stringf("You %svisited %d bazaar",
-                             have.c_str(), place_info.num_visits);
-        if (place_info.num_visits > 1)
-            text += "s";
-        text += ".\n";
+        const PlaceInfo place_info = you.get_place_info(BRANCH_BAZAAR);
+        if (place_info.num_visits > 0)
+        {
+            text += make_stringf("You %svisited %d bazaar",
+                                 have.c_str(), place_info.num_visits);
+            if (place_info.num_visits > 1)
+                text += "s";
+            text += ".\n";
+        }
     }
 
-    place_info = you.get_place_info(BRANCH_ZIGGURAT);
-    if (place_info.num_visits > 0)
     {
-        int num_zigs = place_info.num_visits;
-        text += make_stringf("You %s%s %d ziggurat",
-                             have.c_str(),
-                             (num_zigs == you.zigs_completed) ? "completed"
-                                                              : "visited",
-                             num_zigs);
-        if (num_zigs > 1)
-            text += "s";
-        if (num_zigs != you.zigs_completed && you.zigs_completed)
-            text += make_stringf(" (completing %d)", you.zigs_completed);
-        text += make_stringf(", and %s %d of %s levels",
-                             seen.c_str(), place_info.levels_seen,
-                             num_zigs > 1 ? "their" : "its");
-        if (num_zigs != 1 && !you.zigs_completed)
-            text += make_stringf(" (deepest: %d)", you.zig_max);
-        text += ".\n";
+        const PlaceInfo place_info = you.get_place_info(BRANCH_ZIGGURAT);
+        if (place_info.num_visits > 0)
+        {
+            int num_zigs = place_info.num_visits;
+            text += make_stringf("You %s%s %d ziggurat",
+                                 have.c_str(),
+                                 (num_zigs == you.zigs_completed) ? "completed"
+                                                                  : "visited",
+                                 num_zigs);
+            if (num_zigs > 1)
+                text += "s";
+            if (num_zigs != you.zigs_completed && you.zigs_completed)
+                text += make_stringf(" (completing %d)", you.zigs_completed);
+            text += make_stringf(", and %s %d of %s levels",
+                                 seen.c_str(), place_info.levels_seen,
+                                 num_zigs > 1 ? "their" : "its");
+            if (num_zigs != 1 && !you.zigs_completed)
+                text += make_stringf(" (deepest: %d)", you.zig_max);
+            text += ".\n";
+        }
     }
 
     vector<string> misc_portals;
     for (branch_type br : single_portals)
     {
-        place_info = you.get_place_info(br);
+        const PlaceInfo place_info = you.get_place_info(br);
         if (!place_info.num_visits)
             continue;
         string name = branches[br].shortname;
@@ -434,9 +442,9 @@ static string _denanify(const string &s)
     return out;
 }
 
-static string _sdump_turns_place_info(PlaceInfo place_info, string name = "")
+static string _sdump_turns_place_info(const PlaceInfo place_info, string name = "")
 {
-    PlaceInfo   gi = you.global_info;
+    const PlaceInfo   gi = you.global_info;
     string out;
 
     if (name.empty())
@@ -489,7 +497,7 @@ static void _sdump_turns_by_place(dump_params &par)
 {
     string &text(par.text);
 
-    vector<PlaceInfo> all_visited = you.get_all_place_info(true);
+    const vector<PlaceInfo> all_visited = you.get_all_place_info(true);
 
     text +=
 "Table legend:\n"
@@ -999,7 +1007,7 @@ static void _sdump_kills(dump_params &par)
     par.text += "\n";
 }
 
-static string _sdump_kills_place_info(PlaceInfo place_info, string name = "")
+static string _sdump_kills_place_info(const PlaceInfo place_info, string name = "")
 {
     string out;
 
@@ -1044,7 +1052,7 @@ static void _sdump_kills_by_place(dump_params &par)
 {
     string &text(par.text);
 
-    vector<PlaceInfo> all_visited = you.get_all_place_info(true);
+    const vector<PlaceInfo> all_visited = you.get_all_place_info(true);
 
     string result = "";
 
@@ -1084,6 +1092,7 @@ static void _sdump_overview(dump_params &par)
     string overview =
         formatted_string::parse_string(overview_description_string(false));
     trim_string(overview);
+    linebreak_string(overview, 80);
     par.text += overview;
     par.text += "\n\n";
 }
