@@ -103,7 +103,7 @@ static string _get_version_features()
         {
             result += make_stringf("Game seed: %" PRIu64, crawl_state.seed);
             if (Version::history_size() > 1)
-                result += " (game has been upgraded, seed may be broken)";
+                result += " (game has been upgraded, seed may be affected)";
         }
         else
             result += "Game is not seeded.";
