@@ -20,6 +20,7 @@
 #include "god-passive.h"
 #include "ghost.h"
 #include "hints.h"
+#include "initfile.h"
 #include "invent.h"
 #include "item-prop.h"
 #include "los.h"
@@ -429,6 +430,12 @@ NORETURN void end_game(scorefile_entry &se)
     UNUSED(_exit_type_to_string);
 #endif
 
+#ifndef DISABLE_STICKY_STARTUP_OPTIONS
+    // TODO: update all sticky prefs based on the dead char? Right now this
+    // would lose weapon choice, and random select, as far as I can tell.
+    save_seed_pref();
+#endif
+
     if (!crawl_state.seen_hups)
         more();
 
