@@ -39,14 +39,15 @@ void set_hunger(int new_hunger_level, bool suppress_msg);
 
 bool is_bad_food(const item_def &food);
 bool is_noxious(const item_def &food);
-bool is_inedible(const item_def &item);
+bool is_inedible(const item_def &item, bool temp = true);
 bool is_preferred_food(const item_def &food);
 bool is_forbidden_food(const item_def &food);
 corpse_effect_type determine_chunk_effect(const item_def &carrion);
 corpse_effect_type determine_chunk_effect(corpse_effect_type chunktype);
 mon_intel_type corpse_intelligence(const item_def &corpse);
 
-bool can_eat(const item_def &food, bool suppress_msg, bool check_hunger = true);
+bool can_eat(const item_def &food, bool suppress_msg, bool check_hunger = true,
+                                                        bool temp = true);
 
 bool eat_item(item_def &food);
 
@@ -58,9 +59,8 @@ bool prompt_eat_item(int slot = -1);
 
 int you_max_hunger();
 int you_min_hunger();
-bool you_foodless();
-// Is the player always foodless or just because of a temporary change?
-bool you_foodless_normally();
+bool apply_starvation_penalties();
+bool you_foodless(bool temp = true);
 
 void handle_starvation();
 int hunger_bars(const int hunger);
