@@ -48,7 +48,7 @@ void register_itemlist(lua_State *ls)
 
 static int dgn_item_from_index(lua_State *ls)
 {
-    const int index = luaL_checkint(ls, 1);
+    const int index = luaL_safe_checkint(ls, 1);
 
     item_def *item = &mitm[index];
 
@@ -110,13 +110,13 @@ static int dgn_item_property_set(lua_State *ls)
             item->props[key].get_bool() = lua_toboolean(ls, 4);
             break;
         case 'b':
-            item->props[key].get_byte() = luaL_checkint(ls, 4);
+            item->props[key].get_byte() = luaL_safe_checkint(ls, 4);
             break;
         case 'S':
-            item->props[key].get_short() = luaL_checkint(ls, 4);
+            item->props[key].get_short() = luaL_safe_checkint(ls, 4);
             break;
         case 'i':
-            item->props[key].get_int() = luaL_checkint(ls, 4);
+            item->props[key].get_int() = luaL_safe_checkint(ls, 4);
             break;
         case 'f':
             item->props[key].get_float() = luaL_checknumber(ls, 4);
@@ -125,8 +125,8 @@ static int dgn_item_property_set(lua_State *ls)
             item->props[key].get_string() = luaL_checkstring(ls, 4);
             break;
         case 'C':
-            item->props[key].get_coord() = coord_def(luaL_checkint(ls, 4),
-                                                     luaL_checkint(ls, 5));
+            item->props[key].get_coord() = coord_def(luaL_safe_checkint(ls, 4),
+                                                     luaL_safe_checkint(ls, 5));
             break;
         default:
             luaL_error(ls, "Unknown type: '%s'", type.c_str());
@@ -192,7 +192,7 @@ static int dgn_item_property(lua_State *ls)
 // Returns two arrays: one of floor items, one of shop items.
 static int dgn_stash_items(lua_State *ls)
 {
-    unsigned min_value  = lua_isnumber(ls, 1)  ? luaL_checkint(ls, 1) : 0;
+    unsigned min_value  = lua_isnumber(ls, 1)  ? luaL_safe_checkint(ls, 1) : 0;
     bool skip_stackable = lua_isboolean(ls, 2) ? lua_toboolean(ls, 2)
                                                 : false;
     vector<const item_def*> floor_items;
