@@ -121,7 +121,7 @@ LUAFN(l_mons_add_energy)
 {
     ASSERT_DLUA;
     monster* mons = clua_get_lightuserdata<monster>(ls, lua_upvalueindex(1));
-    mons->speed_increment += luaL_checkint(ls, 1);
+    mons->speed_increment += luaL_safe_checkint(ls, 1);
     return 0;
 }
 MDEFN(add_energy, add_energy)
@@ -230,7 +230,7 @@ static int l_mons_set_hp(lua_State *ls)
     monster* mons =
         clua_get_lightuserdata<monster>(ls, lua_upvalueindex(1));
 
-    int hp = luaL_checkint(ls, 1);
+    int hp = luaL_safe_checkint(ls, 1);
     if (hp <= 0)
     {
         luaL_argerror(ls, 1, "hp must be positive");
@@ -249,7 +249,7 @@ static int l_mons_set_max_hp(lua_State *ls)
     monster* mons =
         clua_get_lightuserdata<monster>(ls, lua_upvalueindex(1));
 
-    int maxhp = luaL_checkint(ls, 1);
+    int maxhp = luaL_safe_checkint(ls, 1);
     if (maxhp <= 0)
     {
         luaL_argerror(ls, 1, "maxhp must be positive");
@@ -320,7 +320,7 @@ static int l_mons_do_set_prop(lua_State *ls)
     // NOTE: number has to be before string, or numbers will get converted
     // into strings.
     else if (lua_isnumber(ls, 2))
-        mons->props[prop_name].get_int() = luaL_checklong(ls, 2);
+        mons->props[prop_name].get_int() = luaL_safe_checklong(ls, 2);
     else if (lua_isstring(ls, 2))
         mons->props[prop_name] = lua_tostring(ls, 2);
     else if (lua_isfunction(ls, 2))
@@ -422,8 +422,8 @@ static int l_mons_do_add_ench(lua_State *ls)
         return 0;
     }
 
-    mons->add_ench(mon_enchant(met, luaL_checkint(ls, 2), 0,
-                               luaL_checkint(ls, 3)));
+    mons->add_ench(mon_enchant(met, luaL_safe_checkint(ls, 2), 0,
+                               luaL_safe_checkint(ls, 3)));
     return 0;
 }
 
@@ -591,7 +591,7 @@ static int monster_set(lua_State *ls)
     if (!strcmp(attr, "beh"))
     {
         const beh_type beh =
-            lua_isnumber(ls, 3) ? static_cast<beh_type>(luaL_checkint(ls, 3)) :
+            lua_isnumber(ls, 3) ? static_cast<beh_type>(luaL_safe_checkint(ls, 3)) :
             lua_isstring(ls, 3) ? behaviour_by_name(lua_tostring(ls, 3))
                                 : NUM_BEHAVIOURS;
 
@@ -599,9 +599,9 @@ static int monster_set(lua_State *ls)
             mw->mons->behaviour = beh;
     }
     else if (!strcmp(attr, "targetx"))
-        mw->mons->target.x = luaL_checkint(ls, 3);
+        mw->mons->target.x = luaL_safe_checkint(ls, 3);
     else if (!strcmp(attr, "targety"))
-        mw->mons->target.y = luaL_checkint(ls, 3);
+        mw->mons->target.y = luaL_safe_checkint(ls, 3);
 
     return 0;
 }
