@@ -12,9 +12,6 @@ class MenuFreeform;
 struct menu_letter;
 struct newgame_def;
 
-bool is_starting_species(species_type species);
-bool is_starting_job(job_type job);
-
 void choose_tutorial_character(newgame_def& ng_choice);
 
 bool choose_game(newgame_def& ng, newgame_def& choice,
