@@ -385,6 +385,8 @@ void setup_game(const newgame_def& ng)
         Options.seed = Options.seed_from_rc;
         crawl_state.type = GAME_TYPE_CUSTOM_SEED;
     }
+    else if (Options.seed && ng.type == GAME_TYPE_NORMAL)
+        Options.seed = 0;
     else if (!Options.seed && ng.type == GAME_TYPE_CUSTOM_SEED)
         crawl_state.type = GAME_TYPE_NORMAL;
     else
@@ -474,6 +476,7 @@ static void _setup_generic(const newgame_def& ng)
 {
     reset_rng(); // initialize rng from Options.seed
     _init_player();
+    you.game_seed = crawl_state.seed;
 
 #if TAG_MAJOR_VERSION == 34
     // Avoid the remove_dead_shops() Gozag fixup in new games: see
@@ -546,6 +549,9 @@ static void _setup_generic(const newgame_def& ng)
         item_colour(item);  // set correct special and colour
     }
 
+    if (you.equip[EQ_WEAPON] > 0)
+        swap_inv_slots(0, you.equip[EQ_WEAPON], false);
+
     // A second pass to apply the item_slot option.
     for (auto &item : you.inv)
     {
