@@ -64,7 +64,7 @@ static void _place_tloc_cloud(const coord_def &origin)
         place_cloud(CLOUD_TLOC_ENERGY, origin, 1 + random2(3), &you);
 }
 
-spret_type cast_disjunction(int pow, bool fail)
+spret cast_disjunction(int pow, bool fail)
 {
     fail_check();
     int rand = random_range(35, 45) + random2(pow / 12);
@@ -72,11 +72,11 @@ spret_type cast_disjunction(int pow, bool fail)
         max(you.duration[DUR_DISJUNCTION] + rand,
         30 + rand));
     contaminate_player(750 + random2(500), true);
-    disjunction();
-    return SPRET_SUCCESS;
+    disjunction_spell();
+    return spret::success;
 }
 
-void disjunction()
+void disjunction_spell()
 {
     int steps = you.time_taken;
     invalidate_agrid(true);
@@ -322,7 +322,7 @@ static coord_def _fuzz_hop_destination(coord_def target)
  *                      therefore fail after selecting a target)
  * @return              Whether the hop succeeded, aborted, or was miscast.
  */
-spret_type frog_hop(bool fail)
+spret frog_hop(bool fail)
 {
     const int hop_range = 2 + you.get_mutation_level(MUT_HOP) * 2; // 4-6
     coord_def target;
@@ -331,7 +331,7 @@ spret_type frog_hop(bool fail)
     while (true)
     {
         if (!_find_cblink_target(target, true, "hop", &tgt))
-            return SPRET_ABORT;
+            return spret::abort;
         if (grid_distance(you.pos(), target) > hop_range)
         {
             mpr("That's out of range!"); // ! targeting
@@ -344,14 +344,14 @@ spret_type frog_hop(bool fail)
     fail_check();
 
     if (!you.attempt_escape(2)) // XXX: 1?
-        return SPRET_SUCCESS; // of a sort
+        return spret::success; // of a sort
 
     // invisible monster that the targeter didn't know to avoid, or similar
     if (target.origin())
     {
         mpr("You tried to hop, but there was no room to land!");
         // TODO: what to do here?
-        return SPRET_SUCCESS; // of a sort
+        return spret::success; // of a sort
     }
 
     if (!cell_is_solid(you.pos())) // should be safe.....
@@ -362,7 +362,7 @@ spret_type frog_hop(bool fail)
     mpr("Boing!");
     you.increase_duration(DUR_NO_HOP, 12 + random2(13));
 
-    return SPRET_SUCCESS; // TODO
+    return spret::success; // TODO
 }
 
 /**
@@ -375,31 +375,31 @@ spret_type frog_hop(bool fail)
  *                      for e.g. ?blink with blurryvis)
  * @return              Whether the blink succeeded, aborted, or was miscast.
  */
-spret_type controlled_blink(bool fail, bool safe_cancel)
+spret controlled_blink(bool fail, bool safe_cancel)
 {
     coord_def target;
     targeter_smite tgt(&you, LOS_RADIUS);
     tgt.obeys_mesmerise = true;
     if (!_find_cblink_target(target, safe_cancel, "blink", &tgt))
-        return SPRET_ABORT;
+        return spret::abort;
 
     fail_check();
 
     if (you.no_tele(true, true, true))
     {
         canned_msg(MSG_STRANGE_STASIS);
-        return SPRET_SUCCESS; // of a sort
+        return spret::success; // of a sort
     }
 
     if (!you.attempt_escape(2))
-        return SPRET_SUCCESS; // of a sort
+        return spret::success; // of a sort
 
     // invisible monster that the targeter didn't know to avoid
     if (monster_at(target))
     {
         mpr("Oops! There was something there already!");
         uncontrolled_blink();
-        return SPRET_SUCCESS; // of a sort
+        return spret::success; // of a sort
     }
 
     _place_tloc_cloud(you.pos());
@@ -410,7 +410,7 @@ spret_type controlled_blink(bool fail, bool safe_cancel)
     crawl_state.cancel_cmd_again();
     crawl_state.cancel_cmd_repeat();
 
-    return SPRET_SUCCESS;
+    return spret::success;
 }
 
 /**
@@ -420,15 +420,15 @@ spret_type controlled_blink(bool fail, bool safe_cancel)
  * @return                  Whether the spell was successfully cast, aborted,
  *                          or miscast.
  */
-spret_type cast_blink(bool fail)
+spret cast_blink(bool fail)
 {
     // effects that cast the spell through the player, I guess (e.g. xom)
     if (you.no_tele(false, false, true))
-        return fail ? SPRET_FAIL : SPRET_SUCCESS; // probably always SUCCESS
+        return fail ? spret::fail : spret::success; // probably always SUCCESS
 
     fail_check();
     uncontrolled_blink();
-    return SPRET_SUCCESS;
+    return spret::success;
 }
 
 /**
@@ -438,13 +438,13 @@ spret_type cast_blink(bool fail)
  * @param safe    Whether it's safe to abort (not e.g. unknown ?blink)
  * @return        Whether the spell was successfully cast, aborted, or miscast.
  */
-spret_type cast_controlled_blink(bool fail, bool safe)
+spret cast_controlled_blink(bool fail, bool safe)
 {
     // don't prompt if it's useless
     if (you.no_tele(true, true, true))
     {
         canned_msg(MSG_STRANGE_STASIS);
-        return SPRET_ABORT;
+        return spret::abort;
     }
 
     if (crawl_state.is_repeating_cmd())
@@ -452,7 +452,7 @@ spret_type cast_controlled_blink(bool fail, bool safe)
         crawl_state.cant_cmd_repeat("You can't repeat controlled blinks.");
         crawl_state.cancel_cmd_again();
         crawl_state.cancel_cmd_repeat();
-        return SPRET_ABORT;
+        return spret::abort;
     }
 
     if (orb_limits_translocation())
@@ -460,7 +460,7 @@ spret_type cast_controlled_blink(bool fail, bool safe)
         if (!yesno("Your blink will be uncontrolled - continue anyway?",
                    false, 'n'))
         {
-            return SPRET_ABORT;
+            return spret::abort;
         }
 
         mprf(MSGCH_ORB, "The Orb prevents control of your translocation!");
@@ -553,12 +553,15 @@ static void _handle_teleport_update(bool large_change, const coord_def old_pos)
 #endif
 }
 
-static bool _teleport_player(bool wizard_tele, bool teleportitis)
+static bool _teleport_player(bool wizard_tele, bool teleportitis,
+                             string reason="")
 {
     if (!wizard_tele && !teleportitis
-        && (crawl_state.game_is_sprint() || you.no_tele(true, true))
+        && (crawl_state.game_is_sprint() || you.no_tele())
             && !player_in_branch(BRANCH_ABYSS))
     {
+        if (!reason.empty())
+            mpr(reason);
         canned_msg(MSG_STRANGE_STASIS);
         return false;
     }
@@ -579,6 +582,8 @@ static bool _teleport_player(bool wizard_tele, bool teleportitis)
         if (teleportitis)
             return false;
 
+        if (!reason.empty())
+            mpr(reason);
         abyss_teleport();
         if (you.pet_target != MHITYOU)
             you.pet_target = MHITNOT;
@@ -629,9 +634,6 @@ static bool _teleport_player(bool wizard_tele, bool teleportitis)
     }
     else
     {
-        if (player_in_branch(BRANCH_LABYRINTH) && teleportitis)
-            return false;
-
         coord_def newpos;
         int tries = 500;
         do
@@ -659,14 +661,18 @@ static bool _teleport_player(bool wizard_tele, bool teleportitis)
                 dprf("teleportitis: no monster near target");
                 return false;
             }
-            else if (you.no_tele(true, true))
+            else if (you.no_tele())
             {
+                if (!reason.empty())
+                    mpr(reason);
                 canned_msg(MSG_STRANGE_STASIS);
                 return false;
             }
             else
             {
                 interrupt_activity(AI_TELEPORT);
+                if (!reason.empty())
+                    mpr(reason);
                 mprf("You are suddenly yanked towards %s nearby monster%s!",
                      mons_near_target > 1 ? "some" : "a",
                      mons_near_target > 1 ? "s" : "");
@@ -761,9 +767,9 @@ bool you_teleport_to(const coord_def where_to, bool move_monsters)
     return true;
 }
 
-void you_teleport_now(bool wizard_tele, bool teleportitis)
+void you_teleport_now(bool wizard_tele, bool teleportitis, string reason)
 {
-    const bool randtele = _teleport_player(wizard_tele, teleportitis);
+    const bool randtele = _teleport_player(wizard_tele, teleportitis, reason);
 
     // Xom is amused by teleports that land you in a dangerous place, unless
     // the player is in the Abyss and teleported to escape from all the
@@ -776,7 +782,7 @@ void you_teleport_now(bool wizard_tele, bool teleportitis)
     }
 }
 
-spret_type cast_portal_projectile(int pow, bool fail)
+spret cast_portal_projectile(int pow, bool fail)
 {
     fail_check();
     if (!you.duration[DUR_PORTAL_PROJECTILE])
@@ -786,17 +792,17 @@ spret_type cast_portal_projectile(int pow, bool fail)
     // Calculate the accuracy bonus based on current spellpower.
     you.attribute[ATTR_PORTAL_PROJECTILE] = pow;
     you.increase_duration(DUR_PORTAL_PROJECTILE, 3 + random2(pow / 2) + random2(pow / 5), 50);
-    return SPRET_SUCCESS;
+    return spret::success;
 }
 
-spret_type cast_apportation(int pow, bolt& beam, bool fail)
+spret cast_apportation(int pow, bolt& beam, bool fail)
 {
     const coord_def where = beam.target;
 
     if (!cell_see_cell(you.pos(), where, LOS_SOLID))
     {
         canned_msg(MSG_SOMETHING_IN_WAY);
-        return SPRET_ABORT;
+        return spret::abort;
     }
 
     // Let's look at the top item in that square...
@@ -806,7 +812,7 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
     if (item_idx == NON_ITEM || !in_bounds(where))
     {
         mpr("You don't see anything to apport there.");
-        return SPRET_ABORT;
+        return spret::abort;
     }
 
     item_def& item = mitm[item_idx];
@@ -815,7 +821,7 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
     if (item_is_stationary(item) && !item_is_stationary_net(item))
     {
         mpr("You cannot apport that!");
-        return SPRET_ABORT;
+        return spret::abort;
     }
 
     fail_check();
@@ -834,7 +840,7 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
                 "The Orb shrieks and becomes a dead weight against your magic!",
                 "The Orb lets out a furious burst of light and becomes "
                     "a dead weight against your magic!");
-            return SPRET_SUCCESS;
+            return spret::success;
         }
         else // Otherwise it's just a noisy little shiny thing
         {
@@ -888,7 +894,7 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
     if (location_on_path == dist)
     {
         mpr("Not with that terrain in the way!");
-        return SPRET_SUCCESS;
+        return spret::success;
     }
     dprf("Apport: new spot is %d/%d", new_spot.x, new_spot.y);
 
@@ -901,15 +907,22 @@ spret_type cast_apportation(int pow, bolt& beam, bool fail)
     // Mark the item as found now.
     origin_set(new_spot);
 
-    return SPRET_SUCCESS;
+    return spret::success;
 }
 
-spret_type cast_golubrias_passage(const coord_def& where, bool fail)
+spret cast_golubrias_passage(const coord_def& where, bool fail)
 {
     if (orb_limits_translocation())
     {
         mprf(MSGCH_ORB, "The Orb prevents you from opening a passage!");
-        return SPRET_ABORT;
+        return spret::abort;
+    }
+
+    if (player_in_branch(BRANCH_GAUNTLET))
+    {
+        mprf(MSGCH_ORB, "A magic seal in the Gauntlet prevents you from "
+                "opening a passage!");
+        return spret::abort;
     }
 
     // randomize position a bit to make it not as useful to use on monsters
@@ -955,7 +968,7 @@ spret_type cast_golubrias_passage(const coord_def& where, bool fail)
         else
             // XXX: bleh, dumb message
             mpr("Creating a passage of Golubria requires sufficient empty space.");
-        return SPRET_ABORT;
+        return spret::abort;
     }
 
     fail_check();
@@ -968,13 +981,13 @@ spret_type cast_golubrias_passage(const coord_def& where, bool fail)
     if (!trap || !trap2)
     {
         mpr("Something buggy happened.");
-        return SPRET_ABORT;
+        return spret::abort;
     }
 
     trap->reveal();
     trap2->reveal();
 
-    return SPRET_SUCCESS;
+    return spret::success;
 }
 
 static int _disperse_monster(monster& mon, int pow)
@@ -994,7 +1007,7 @@ static int _disperse_monster(monster& mon, int pow)
     return true;
 }
 
-spret_type cast_dispersal(int pow, bool fail)
+spret cast_dispersal(int pow, bool fail)
 {
     fail_check();
     const int radius = spell_range(SPELL_DISPERSAL, pow);
@@ -1004,14 +1017,15 @@ spret_type cast_dispersal(int pow, bool fail)
     {
         mpr("The air shimmers briefly around you.");
     }
-    return SPRET_SUCCESS;
+    return spret::success;
 }
 
-int gravitas_range(int pow, int strength)
+int gravitas_range(int pow)
 {
-    return max(0, min(LOS_RADIUS, (int)isqrt((pow/10 + 1) / strength)));
+    return pow >= 80 ? 3 : 2;
 }
 
+
 #define GRAVITY "by gravitational forces"
 
 static void _attract_actor(const actor* agent, actor* victim,
@@ -1034,6 +1048,7 @@ static void _attract_actor(const actor* agent, actor* victim,
         return;
     }
 
+    const coord_def starting_pos = victim->pos();
     for (int i = 0; i < strength; i++)
     {
         ray.advance();
@@ -1053,7 +1068,7 @@ static void _attract_actor(const actor* agent, actor* victim,
         else if (!victim->is_habitable(newpos))
             break;
         else
-            victim->move_to_pos(newpos, false);
+            victim->move_to_pos(newpos);
 
         if (auto mons = victim->as_monster())
         {
@@ -1064,6 +1079,12 @@ static void _attract_actor(const actor* agent, actor* victim,
         if (victim->pos() == pos)
             break;
     }
+    if (starting_pos != victim->pos())
+    {
+        victim->apply_location_effects(starting_pos);
+        if (victim->is_monster())
+            mons_relocated(victim->as_monster());
+    }
 }
 
 bool fatal_attraction(const coord_def& pos, const actor *agent, int pow)
@@ -1075,11 +1096,11 @@ bool fatal_attraction(const coord_def& pos, const actor *agent, int pow)
             continue;
 
         const int range = (pos - ai->pos()).rdist();
-        const int strength =
-            min(LOS_RADIUS, ((pow + 100) / 20) / (range*range));
-        if (strength <= 0)
+        if (range > gravitas_range(pow))
             continue;
 
+        const int strength = ((pow + 100) / 20) / (range*range);
+
         affected = true;
         _attract_actor(agent, *ai, pos, pow, strength);
     }
@@ -1087,12 +1108,12 @@ bool fatal_attraction(const coord_def& pos, const actor *agent, int pow)
     return affected;
 }
 
-spret_type cast_gravitas(int pow, const coord_def& where, bool fail)
+spret cast_gravitas(int pow, const coord_def& where, bool fail)
 {
     if (cell_is_solid(where))
     {
         canned_msg(MSG_UNTHINKING_ACT);
-        return SPRET_ABORT;
+        return spret::abort;
     }
 
     fail_check();
@@ -1107,7 +1128,7 @@ spret_type cast_gravitas(int pow, const coord_def& where, bool fail)
                                                          .c_str()
                                    : "empty space");
     fatal_attraction(where, &you, pow);
-    return SPRET_SUCCESS;
+    return spret::success;
 }
 
 /**
