@@ -552,34 +552,39 @@ bool game_state::game_standard_levelgen() const
     return game_is_normal() || game_is_hints();
 }
 
+bool game_state::game_is_valid_type() const
+{
+    return type < NUM_GAME_TYPE;
+}
+
 bool game_state::game_is_normal() const
 {
-    ASSERT(type < NUM_GAME_TYPE);
+    ASSERT(game_is_valid_type());
     return type == GAME_TYPE_NORMAL || type == GAME_TYPE_CUSTOM_SEED
-                                    ||type == GAME_TYPE_UNSPECIFIED;
+                                    || type == GAME_TYPE_UNSPECIFIED;
 }
 
 bool game_state::game_is_tutorial() const
 {
-    ASSERT(type < NUM_GAME_TYPE);
+    ASSERT(game_is_valid_type());
     return type == GAME_TYPE_TUTORIAL;
 }
 
 bool game_state::game_is_arena() const
 {
-    ASSERT(type < NUM_GAME_TYPE);
+    ASSERT(game_is_valid_type());
     return type == GAME_TYPE_ARENA;
 }
 
 bool game_state::game_is_sprint() const
 {
-    ASSERT(type < NUM_GAME_TYPE);
+    ASSERT(game_is_valid_type());
     return type == GAME_TYPE_SPRINT;
 }
 
 bool game_state::game_is_hints() const
 {
-    ASSERT(type < NUM_GAME_TYPE);
+    ASSERT(game_is_valid_type());
     return type == GAME_TYPE_HINTS;
 }
 
@@ -611,11 +616,15 @@ string game_state::game_type_name_for(game_type _type)
         return "Arena";
     case GAME_TYPE_SPRINT:
         return "Dungeon Sprint";
+    case NUM_GAME_TYPE:
+        return "Unknown";
     }
 }
 
 string game_state::game_savedir_path() const
 {
+    if (!game_is_valid_type())
+        return ""; // a game from the future -- avoid the ASSERT below
     return game_is_sprint()? "sprint/" : "";
 }
 
