@@ -154,6 +154,8 @@ public:
     virtual void set_mod_state(tiles_key_mod mod) = 0;
     virtual void set_mouse_cursor(mouse_cursor_type id) = 0;
     virtual unsigned short get_mouse_state(int *x, int *y) const = 0;
+    virtual string get_clipboard() = 0;
+    virtual bool has_clipboard() = 0;
 
     // System time functions
     virtual unsigned int set_timer(unsigned int interval,
